@@ -267,6 +267,14 @@ bool zcbor_uint64_decode(zcbor_state_t *state, uint64_t *result)
 }
 
 
+#ifdef ZCBOR_SUPPORTS_SIZE_T
+bool zcbor_size_decode(zcbor_state_t *state, size_t *result)
+{
+	return value_extract(state, result, sizeof(size_t));
+}
+#endif
+
+
 bool zcbor_uint32_expect(zcbor_state_t *state, uint32_t result)
 {
 	return zcbor_uint64_expect(state, result);
@@ -288,6 +296,14 @@ bool zcbor_uint64_expect(zcbor_state_t *state, uint64_t result)
 }
 
 
+#ifdef ZCBOR_SUPPORTS_SIZE_T
+bool zcbor_size_expect(zcbor_state_t *state, size_t result)
+{
+	return zcbor_uint64_expect(state, result);
+}
+#endif
+
+
 static bool str_start_decode(zcbor_state_t *state,
 		struct zcbor_string *result, zcbor_major_type_t exp_major_type)
 {
@@ -316,8 +332,8 @@ static bool str_overflow_check(zcbor_state_t *state, struct zcbor_string *result
 
 bool zcbor_bstr_start_decode(zcbor_state_t *state, struct zcbor_string *result)
 {
+	struct zcbor_string dummy;
 	if (result == NULL) {
-		struct zcbor_string dummy;
 		result = &dummy;
 	}
 
@@ -907,8 +923,8 @@ bool zcbor_present_decode(uint_fast32_t *present,
 }
 
 
-bool zcbor_new_decode_state(zcbor_state_t *state_array, uint_fast32_t n_states,
+void zcbor_new_decode_state(zcbor_state_t *state_array, uint_fast32_t n_states,
 		const uint8_t *payload, size_t payload_len, uint_fast32_t elem_count)
 {
-	return zcbor_new_state(state_array, n_states, payload, payload_len, elem_count);
+	zcbor_new_state(state_array, n_states, payload, payload_len, elem_count);
 }
